@@ -1,5 +1,10 @@
 
 sort_mat <- function(x,by.row=FALSE,descending=FALSE,stable=FALSE,parallel=FALSE) {
+	if(by.row)
+		.Deprecated("Rfast::rowSort")
+	else
+		.Deprecated("Rfast::colSort")
+
 	if(parallel){
 	  	if(stable){
 			.Call(Rfast_stable_sort_mat_p,x,descending,by.row)
