@@ -18,23 +18,23 @@ NumericMatrix euclidean_dist(NumericMatrix x,const bool sqr){
   double a;
   int i,j;
   if(sqr){
-    for(i=0;i<ncl-1;++i){
-      xv=xx.col(i);
-      for(j=i+1;j<ncl;++j){
-        a=sum(square(xx.col(j)-xv));
-        f(i,j)=a;
-        f(j,i)=a;
+      for(i=0;i<ncl-1;++i){
+        xv=xx.col(i);
+        for(j=i+1;j<ncl;++j){
+          a=sum(square(xx.col(j)-xv));
+          f(i,j)=a;
+          f(j,i)=a;
+        }
       }
-    }
   }else{
-    for(i=0;i<ncl-1;++i){
-      xv=xx.col(i);
-      for(j=i+1;j<ncl;++j){
-        a=std::sqrt(sum(square(xv-xx.col(j))));
-        f(i,j)=a;
-        f(j,i)=a;
+      for(i=0;i<ncl-1;++i){
+        xv=xx.col(i);
+        for(j=i+1;j<ncl;++j){
+          a=std::sqrt(sum(square(xx.col(j)-xv)));
+          f(i,j)=a;
+          f(j,i)=a;
+        }
       }
-    }
   }
   return f;
 }
@@ -46,14 +46,14 @@ NumericMatrix manhattan_dist(NumericMatrix x){
   colvec xv(nrw);
   double a;
   int i,j;
-  for(i=0;i<ncl-1;++i){
-    xv=xx.col(i);
-    for(j=i+1;j<ncl;++j){
-      a=sum(abs(xv-xx.col(j)));
-      f(i,j)=a;
-      f(j,i)=a;
+    for(i=0;i<ncl-1;++i){
+      xv=xx.col(i);
+      for(j=i+1;j<ncl;++j){
+        a=sum(abs(xv-xx.col(j)));
+        f(i,j)=a;
+        f(j,i)=a;
+      }
     }
-  }
   return f;
 }
 
@@ -66,23 +66,23 @@ NumericMatrix hellinger_dist(NumericMatrix x,const bool sqr){
   double a;
   int i,j;
   if(sqr){
-    for(i=0;i<ncl-1;++i){
-      xv=xx.col(i);
-      for(j=i+1;j<ncl;++j){
-        a=sum(square(xv-xx.col(j)))*0.5;
-        f(i,j)=a;
-        f(j,i)=a;
+      for(i=0;i<ncl-1;++i){
+        xv=xx.col(i);
+        for(j=i+1;j<ncl;++j){
+          a=sum(square(xv-xx.col(j)))*0.5;
+          f(i,j)=a;
+          f(j,i)=a;
+        }
       }
-    }
   }else{
-    for(i=0;i<ncl-1;++i){
-      xv=xx.col(i);
-      for(j=i+1;j<ncl;++j){
-        a=p*std::sqrt(sum(square(xv-xx.col(j))));
-        f(i,j)=a;
-        f(j,i)=a;
+      for(i=0;i<ncl-1;++i){
+        xv=xx.col(i);
+        for(j=i+1;j<ncl;++j){
+          a=p*std::sqrt(sum(square(xv-xx.col(j))));
+          f(i,j)=a;
+          f(j,i)=a;
+        }
       }
-    }
   }
   return f;
 }
@@ -94,15 +94,15 @@ NumericMatrix max_dist(NumericMatrix x){
   colvec xv(nrw),tmp(nrw);
   double a;
   int i,j;
-  for(i=0;i<ncl-1;++i){
-    xv=xx.col(i);
-    for(j=i+1;j<ncl;++j){
-      tmp=abs(xv-xx.col(j));
-      a=tmp.at(tmp.index_max());
-      f(i,j)=a;
-      f(j,i)=a;
+    for(i=0;i<ncl-1;++i){
+      xv=xx.col(i);
+      for(j=i+1;j<ncl;++j){
+        tmp=abs(xv-xx.col(j));
+        a=tmp.at(tmp.index_max());
+        f(i,j)=a;
+        f(j,i)=a;
+      }
     }
-  }
   return f;
 }
 
@@ -113,15 +113,15 @@ NumericMatrix min_dist(NumericMatrix x){
   colvec xv(nrw);
   double a;
   int i,j;
-  for(i=0;i<ncl-1;++i){
-    xv=xx.col(i);
-    for(j=i+1;j<ncl;++j){
-      xv=abs(xx.col(j)-xv);
-      a=xv.at(xv.index_min());
-      f(i,j)=a;
-      f(j,i)=a;
-    }
-  }
+    for(i=0;i<ncl-1;++i){
+      xv=xx.col(i);
+      for(j=i+1;j<ncl;++j){
+        xv=abs(xx.col(j)-xv);
+        a=xv.at(xv.index_min());
+        f(i,j)=a;
+        f(j,i)=a;
+      }
+    } 
   return f;
 }
 
@@ -133,14 +133,15 @@ NumericMatrix minkowski_dist(NumericMatrix x,const double p){
   colvec xv(nrw);
   double a;
   int i,j;
-  for(i=0;i<ncl-1;++i){
-    xv=xx.col(i);
-    for(j=i+1;j<ncl;++j){      
-      a=pow(sum_with<std::pow,colvec>(abs(xv-xx.col(j)),p),p_1);
-      f(i,j)=a;
-      f(j,i)=a;
-    }
-  }
+
+    for(i=0;i<ncl-1;++i){
+      xv=xx.col(i);
+      for(j=i+1;j<ncl;++j){      
+        a=pow(sum_with<std::pow,colvec>(abs(xv-xx.col(j)),p),p_1);
+        f(i,j)=a;
+        f(j,i)=a;
+      }
+    } 
   return f;
 }
 
@@ -151,15 +152,16 @@ NumericMatrix canberra1_dist(NumericMatrix x){
   colvec xv(nrw),yv(nrw);
   double a;
   int i,j;
-  for(i=0;i<ncl-1;++i){
-    xv=xx.col(i);
-    for(j=i+1;j<ncl;++j){
-      yv=xx.col(j);
-      a=sum(abs((xv-yv)/(xv+yv)));
-      f(i,j)=a;
-      f(j,i)=a;
-    }
-  }
+
+    for(i=0;i<ncl-1;++i){
+      xv=xx.col(i);
+      for(j=i+1;j<ncl;++j){
+        yv=xx.col(j);
+        a=sum(abs((xv-yv)/(xv+yv)));
+        f(i,j)=a;
+        f(j,i)=a;
+      }
+    } 
   return f;
 }
 
@@ -170,15 +172,16 @@ NumericMatrix canberra2_dist(NumericMatrix x){
   colvec xv(nrw),yv(nrw);
   double a;
   int i,j;
-  for(i=0;i<ncl-1;++i){
-    xv=xx.col(i);
-    for(j=i+1;j<ncl;++j){
-      yv=xx.col(j);
-      a=sum(abs(xv-yv)/(abs(xv)-abs(yv)));
-      f(i,j)=a;
-      f(j,i)=a;
-    }
-  }
+  
+    for(i=0;i<ncl-1;++i){
+      xv=xx.col(i);
+      for(j=i+1;j<ncl;++j){
+        yv=xx.col(j);
+        a=sum(abs(xv-yv)/(abs(xv)-abs(yv)));
+        f(i,j)=a;
+        f(j,i)=a;
+      }
+    } 
   return f;
 }
 
@@ -190,14 +193,15 @@ NumericMatrix total_variation_dist(NumericMatrix x){
   colvec xv(nrw);
   double a;
   int i,j;
-  for(i=0;i<ncl-1;++i){
-    xv=xx.col(i);
-    for(j=i+1;j<ncl;++j){
-      a=0.5*sum(abs(xv-xx.col(j)));
-      f(i,j)=a;
-      f(j,i)=a;
-    }
-  }
+  
+    for(i=0;i<ncl-1;++i){
+      xv=xx.col(i);
+      for(j=i+1;j<ncl;++j){
+        a=0.5*sum(abs(xv-xx.col(j)));
+        f(i,j)=a;
+        f(j,i)=a;
+      }
+    } 
   return f;
 }
 
@@ -210,15 +214,39 @@ NumericMatrix kullback_leibler_dist(NumericMatrix x){
   double a;
   int i,j;
   fill_with<std::log,double*,double*>(x.begin(),x.end(),log_xx.begin());
-  for(i=0;i<ncl-1;++i){
-    xv=xx.col(i);
-    log_xv=log_xx.col(i);
-    for(j=i+1;j<ncl;++j){
-      a=sum((xv-xx.col(j))%(log_xv-log_xx.col(j)));
-      f(i,j)=a;
-      f(j,i)=a;
-    }
-  }
+
+    for(i=0;i<ncl-1;++i){
+      xv=xx.col(i);
+      log_xv=log_xx.col(i);
+      for(j=i+1;j<ncl;++j){
+        a=sum((xv-xx.col(j))%(log_xv-log_xx.col(j)));
+        f(i,j)=a;
+        f(j,i)=a;
+      }
+    } 
+  return f;
+}
+
+//[[Rcpp::export]]
+NumericMatrix jensen_shannon_dist(NumericMatrix x){
+    const int ncl=x.ncol(),nrw=x.nrow();
+    NumericMatrix f(ncl,ncl),log_x(nrw,ncl);
+    mat xx(x.begin(),nrw,ncl,false),log_xx(log_x.begin(),nrw,ncl,false);
+    colvec xv(nrw),log_xv(nrw);
+    double a;
+    const double log2=std::log(2);
+    int i,j;
+    fill_with<std::log,double*,double*>(x.begin(),x.end(),log_xx.begin());
+    
+    for(i=0;i<ncl-1;++i){
+        xv=xx.col(i);
+        log_xv=log_xx.col(i);
+        for(j=i+1;j<ncl;++j){
+            a=sum((xv+xx.col(j))%(log2-arma::log(xv+xx.col(j)))+xv%log_xv+xx.col(j)%log_xx.col(j));
+            f(i,j)=a;
+            f(j,i)=a;
+        }
+    } 
   return f;
 }
 
@@ -230,14 +258,15 @@ NumericMatrix bhattacharyya_dist(NumericMatrix x){
   colvec xv(nrw);
   double a;
   int i,j;
-  for(i=0;i<ncl-1;++i){
-    xv=xx.col(i);
-    for(j=i+1;j<ncl;++j){
-      a=sum(sqrt(abs(xv%xx.col(j))));
-      f(i,j)=a;
-      f(j,i)=a;
-    }
-  }
+  
+    for(i=0;i<ncl-1;++i){
+      xv=xx.col(i);
+      for(j=i+1;j<ncl;++j){
+        a=sum(sqrt(abs(xv%xx.col(j))));
+        f(i,j)=a;
+        f(j,i)=a;
+      }
+    } 
   return f;
 }
 
@@ -250,15 +279,16 @@ NumericMatrix itakura_saito_dist(NumericMatrix x){
   double a;
   int i,j;
   fill_with<std::log,double*,double*>(x.begin(),x.end(),log_xx.begin());
-  for(i=0;i<ncl-1;++i){
-    xv=xx.col(i);
-    log_xv=log_xx.col(i);
-    for(j=i+1;j<ncl;++j){
-      a=sum((xv-xx.col(j)-log_xv-log_xx.col(j))-1);
-      f(i,j)=a;
-      f(j,i)=a;
-    }
-  }
+
+    for(i=0;i<ncl-1;++i){
+      xv=xx.col(i);
+      log_xv=log_xx.col(i);
+      for(j=i+1;j<ncl;++j){
+        a=sum((xv-xx.col(j)-log_xv-log_xx.col(j))-1);
+        f(i,j)=a;
+        f(j,i)=a;
+      }
+    } 
   return f;
 }
 
@@ -285,8 +315,10 @@ NumericMatrix dist(NumericMatrix x,const string method,const bool sqr,const int
     return hellinger_dist(x,sqr);
   }else if(method == "total_variation"){
     return total_variation_dist(x);
-  }else if(method == "kullback_leibler" || method == "jensen_shannon"){
+  }else if(method == "kullback_leibler"){
     return kullback_leibler_dist(x);
+  }else if(method == "jensen_shannon"){
+    return jensen_shannon_dist(x);
   }else if(method == "itakura_saito"){
     return itakura_saito_dist(x);
   }
@@ -301,7 +333,7 @@ BEGIN_RCPP
     traits::input_parameter< const string >::type method(methodSEXP);
     traits::input_parameter< const bool >::type sqr(sqrSEXP);
     traits::input_parameter< const int >::type p(pSEXP);
-    __result = wrap(dist(x,method,sqr,p));
+    __result = dist(x,method,sqr,p);
     return __result;
 END_RCPP
 }
